@@ -5,9 +5,8 @@ OC.L10N.register(
     "Error" : "Fout",
     "New note" : "Nuwe nota",
     "There are unsaved notes. Leaving the page will discard all changes!" : "Daar is ongestoorde veranderinge. Indien die bladsy gesluit word sal alle veranderinge geskrap word!",
-    "Settings" : "Instellings",
-    "path to notes" : "pad na notas",
     "File extension for new notes" : "Lêeruitbreiding vir nuwe notas",
+    "Insert image" : "Voer beeld in",
     "All notes" : "Alle notas",
     "Categories" : "Kategorieë",
     "Loading …" : "Laai …",
@@ -18,8 +17,10 @@ OC.L10N.register(
     "Delete note" : "Skrap nota",
     "Remove from favorites" : "Verwyder uit gunstelinge",
     "Add to favorites" : "Voeg by gunstelinge",
+    "Use current version" : "Gebruik huidige weergawe",
     "Details" : "Besonderhede",
     "Edit" : "Wysig",
+    "Preview" : "Voorskou",
     "Category" : "Kategorie",
     "Uncategorized" : "Ongekategorieseer",
     "Saving failed!" : "Stoor het misluk!",
