@@ -6,7 +6,9 @@ OC.L10N.register(
     "New note" : "New note",
     "Distraction-free notes and writing" : "Distraction-free notes and writing",
     "There are unsaved notes. Leaving the page will discard all changes!" : "There are unsaved notes. Leaving the page will discard all changes!",
-    "Settings" : "Settings",
+    "Display mode for notes" : "Display mode for notes",
+    "Open in edit mode" : "Open in edit mode",
+    "Open in preview mode" : "Open in preview mode",
     "No notes yet" : "No notes yet",
     "All notes" : "All notes",
     "Categories" : "Categories",
