@@ -4,10 +4,13 @@ OC.L10N.register(
     "Notes" : "Notas",
     "Error" : "Error",
     "New note" : "Nueva nota",
-    "Settings" : "Ajustes",
+    "Display mode for notes" : "Modo de visualización para notas",
+    "Open in edit mode" : "Abrir en modo editor",
+    "Open in preview mode" : "Abrir en modo de vista previa",
     "No notes yet" : "Aún no hay notas",
     "All notes" : "Todas la notas",
     "Categories" : "Categoría",
+    "Loading …" : "Cargando …",
     "Today" : "Hoy",
     "Yesterday" : "Ayer",
     "This week" : "Esta semana",
@@ -23,8 +26,8 @@ OC.L10N.register(
     "Preview" : "Vista previa",
     "Category" : "Categoría",
     "Uncategorized" : "Sin categoría",
-    "_%n word_::_%n words_" : ["%n palabra","%n palabras"],
+    "_%n word_::_%n words_" : ["%n palabra","%n palabras","%n palabras"],
     "Android app" : "Aplicación android",
     "iOS app" : "Aplicación iOS"
 },
-"nplurals=2; plural=(n != 1);");
+"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
