@@ -13,13 +13,20 @@ OC.L10N.register(
     "There are unsaved notes. Leaving the page will discard all changes!" : "Havaittiin tallentamattomia muistiinpanoja. Sivulta poistuminen hylkää kaikki muutokset!",
     "_Deleted {number} note_::_Deleted {number} notes_" : ["Poistettu {number} muistiinpano","Poistettu {number} muistiinpanoa"],
     "_Recovered {number} note_::_Recovered {number} notes_" : ["Palautettu {number} muistiinpano","Palautettu {number} muistiinpanoa"],
-    "Settings" : "Asetukset",
     "Folder to store your notes" : "Kansio johon muistiinpanot tallennetaan",
-    "path to notes" : "polku muistiinpanoihin",
+    "Root directory" : "Juurihakemisto",
     "File extension for new notes" : "Tiedostopääte uusille muistiinpanoille",
+    "Display mode for notes" : "Muistiinpanojen esitystapa",
+    "User defined" : "Käyttäjän määrittelemä",
     "Open in edit mode" : "Avaa muokkaustilassa",
     "Open in preview mode" : "Avaa esikatselutilassa",
     "No notes yet" : "Ei muistiinpanoja",
+    "Upload image" : "Lataa kuva",
+    "Insert image" : "Lisää kuva",
+    "Select an image" : "Valitse kuva",
+    "You cannot select images outside of your notes folder. Your notes folder is: {folder}" : "Et voi valita kuvia muistiinpanohakemiston ulkopuolelta. Muistiinpanojesi hakemisto: {folder}",
+    "Wrong image" : "Väärä kuva",
+    "The file was not uploaded. Check your server logs." : "Tiedostoa ei ladattu. Tarkista palvelimen lokitiedot.",
     "All notes" : "Kaikki muistiinpanot",
     "Categories" : "Luokat",
     "Loading …" : "Ladataan…",
@@ -35,6 +42,7 @@ OC.L10N.register(
     "Remove from favorites" : "Poista suosikeista",
     "Add to favorites" : "Lisää suosikkeihin",
     "Error during preparing note for deletion." : "Virhe valmisteltaessa muistiinpanon poistamista.",
+    "The note has been changed in another session. Please choose which version should be saved." : "Muistiinpanoa on muutettu toisessa sessiossa. Valitse, kumpi versio tallennetaan.",
     "Use version from server" : "Käytä versiota palvelimelta",
     "Use current version" : "Käytä nykyistä versiota",
     "Empty note" : "Tyhjä muistiinpano",
@@ -45,7 +53,9 @@ OC.L10N.register(
     "Preview" : "Esikatselu",
     "Exit full screen" : "Poistu koko näytön tilasta",
     "Full screen" : "Koko näytön tila",
+    "Note is read-only. You cannot change it." : "Muistiinpano on kirjoitussuojattu. Et voi tehdä siihen muutoksia.",
     "Save failed. Click to retry." : "Tallennus epäonnistui. Napsauta yrittääksesi uudelleen.",
+    "Update conflict. Click for resolving manually." : "Konflikti päivityksessä. Klikkaa ratkaistaksesi se manuaalisesti.",
     "Error from Nextcloud server: {msg}" : "Virhe Nextcloud-palvelimelta: {msg}",
     "Set category" : "Aseta luokka",
     "Category" : "Luokka",
