@@ -6,11 +6,13 @@ OC.L10N.register(
     "New note" : "Nýr minnispunktur",
     "Distraction-free notes and writing" : "Augljós ritun og skoðun minnispunkta",
     "There are unsaved notes. Leaving the page will discard all changes!" : "Það eru óvistaðir minnispunktar. Ef farið er af síðunni munu allar breytingar tapast!",
-    "Settings" : "Stillingar",
     "Folder to store your notes" : "Mappa til að geyma minnispunktana þína",
-    "path to notes" : "slóð að minnispunktum",
     "File extension for new notes" : "Skráarending fyrir nýja minnispunkta",
+    "Display mode for notes" : "Birtingarhamur minnispunkta",
+    "Open in edit mode" : "Opna í breytingaham",
+    "Open in preview mode" : "Opna í forskoðunarham",
     "No notes yet" : "Engir minnispunktar ennþá",
+    "Insert image" : "Setja inn mynd",
     "All notes" : "Allir minnispunktar",
     "Categories" : "Flokkar",
     "Loading …" : "Hleð inn …",
@@ -22,6 +24,7 @@ OC.L10N.register(
     "Delete note" : "Eyða minnispunkti",
     "Remove from favorites" : "Fjarlægja úr eftirlætum",
     "Add to favorites" : "Bæta í eftirlæti",
+    "Use current version" : "Nota fyrirliggjandi útgáfu",
     "Details" : "Details",
     "Edit" : "Breyta",
     "Preview" : "Forskoðun",
