@@ -9,11 +9,13 @@ OC.L10N.register(
     "Deleted {title}" : "{title} ištrinti",
     "Undo Delete" : "Atšaukti ištrynimą",
     "There are unsaved notes. Leaving the page will discard all changes!" : "Yra neįrašytų užrašų. Išėjus iš šio puslapio, visi pakeitimai bus atmesti!",
-    "Settings" : "Nustatymai",
     "Folder to store your notes" : "Aplankas, kuriame saugoti jūsų užrašus",
-    "path to notes" : "kelias į užrašus",
     "File extension for new notes" : "Naujų užrašų failo prievardis",
+    "Display mode for notes" : "Užrašų rodinio veiksena",
+    "Open in edit mode" : "Atverti redagavimo veiksenoje",
+    "Open in preview mode" : "Atverti peržiūros veiksenoje",
     "No notes yet" : "Nėra užrašų",
+    "Insert image" : "Įterpti paveikslą",
     "All notes" : "Visi užrašai",
     "Categories" : "Kategorijos",
     "Loading …" : "Įkeliama…",
@@ -27,6 +29,7 @@ OC.L10N.register(
     "Delete note" : "Ištrinti užrašus",
     "Remove from favorites" : "Šalinti iš mėgstamų",
     "Add to favorites" : "Pridėti į mėgstamus",
+    "Use current version" : "Naudoti esamą versiją",
     "Empty note" : "Tušti užrašai",
     "Write …" : "Rašykite…",
     "Details" : "Išsamiau",
